netapp_ontap.resources.snapshot_policy_schedule API documentation
Description: Copyright &copy; 2020 NetApp Inc. All rights reserved …

# Module `netapp_ontap.resources.snapshot_policy_schedule`

Copyright © 2020 NetApp Inc. All rights reserved.

## Overview

In ONTAP, scheduled Snapshot copy creation works based on the schedules associated with Snapshot copy policies. ONTAP provides six cluster-wide schedules: "5min", "8hour", "hourly", "daily", "weekly" and "monthly". A Snapshot copy policy is created using at least one of these schedules and up to 5 schedules can be associated with a Snapshot copy policy. A Snapshot copy policy can be linked to a storage object and based on the schedule in the policy, Snapshot copies are created on the object at that interval. Each schedule in a Snapshot copy policy has a Snapshot copy name prefix attached to it. Every Snapshot copy created using this policy has this prefix in its name. There is also a retention count associated with every schedule. This count indicates the maximum number of Snapshot copies that can exist for a given schedule. Once the Snapshot copy count reaches the retention count, on the next create operation, the oldest Snapshot copy is deleted. A schedule can be added, modified or deleted from a Snapshot copy policy.

## Snapshot copy policy schedule APIs

The following APIs are used to perform operations related to Snapshot copy policy schedules:

- POST /api/storage/snapshot-policies/{snapshot_policy.uuid}/schedules/
- GET /api/storage/snapshot-policies/{snapshot_policy.uuid}/schedules/
- GET /api/storage/snapshot-policies/{snapshot_policy.uuid}/schedules/{schedule.uuid}
- PATCH /api/storage/snapshot-policies/{snapshot_policy.uuid}/schedules/{schedule.uuid}
- DELETE /api/storage/snapshot-policies/{snapshot_policy.uuid}/schedules/{schedule.uuid}

## Examples

### Adding schedule to a Snapshot copy policy

The POST operation is used to create a schedule for a Snapshot copy policy with the specified attributes.

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import SnapshotPolicySchedule

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = SnapshotPolicySchedule("32a0841a-818e-11e9-b4f4-005056bbab9c")
        resource.schedule.uuid = "7c985d80-818a-11e9-b4f4-005056bbab9c"
        resource.count = "5"
        resource.prefix = "new_hourly"
        resource.post(hydrate=True)
        print(resource)

Try it out

    SnapshotPolicySchedule(
        {
            "snapshot_policy": {"uuid": "32a0841a-818e-11e9-b4f4-005056bbab9c"},
            "schedule": {"uuid": "7c985d80-818a-11e9-b4f4-005056bbab9c"},
            "prefix": "new_monthly",
            "count": 5,
        }
    )

### Retrieving Snapshot copy policy schedules

The GET operation is used to retrieve Snapshot copy policy schedules.

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import SnapshotPolicySchedule

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        print(
            list(
                SnapshotPolicySchedule.get_collection(
                    "32a0841a-818e-11e9-b4f4-005056bbab9c"
                )
            )
        )

Try it out

    [
        SnapshotPolicySchedule(
            {
                "snapshot_policy": {"uuid": "32a0841a-818e-11e9-b4f4-005056bbab9c"},
                "schedule": {
                    "uuid": "63d017dc-818a-11e9-b4f4-005056bbab9c",
                    "name": "5min",
                },
            }
        ),
        SnapshotPolicySchedule(
            {
                "snapshot_policy": {"uuid": "32a0841a-818e-11e9-b4f4-005056bbab9c"},
                "schedule": {
                    "uuid": "64a5c5da-818a-11e9-b4f4-005056bbab9c",
                    "name": "8hour",
                },
            }
        ),
        SnapshotPolicySchedule(
            {
                "snapshot_policy": {"uuid": "32a0841a-818e-11e9-b4f4-005056bbab9c"},
                "schedule": {
                    "uuid": "63e21a3e-818a-11e9-b4f4-005056bbab9c",
                    "name": "daily",
                },
            }
        ),
        SnapshotPolicySchedule(
            {
                "snapshot_policy": {"uuid": "32a0841a-818e-11e9-b4f4-005056bbab9c"},
                "schedule": {
                    "uuid": "7c985d80-818a-11e9-b4f4-005056bbab9c",
                    "name": "monthly",
                },
            }
        ),
    ]

### Retrieving the attributes of a specific Snapshot copy policy schedule

The GET operation is used to retrieve the attributes of a specific Snapshot copy policy schedule.

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import SnapshotPolicySchedule

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = SnapshotPolicySchedule(
            "32a0841a-818e-11e9-b4f4-005056bbab9c",
            **{"schedule.uuid": "7c985d80-818a-11e9-b4f4-005056bbab9c"}
        )
        resource.get()
        print(resource)

Try it out

    SnapshotPolicySchedule(
        {
            "snapshot_policy": {"uuid": "32a0841a-818e-11e9-b4f4-005056bbab9c"},
            "schedule": {"uuid": "7c985d80-818a-11e9-b4f4-005056bbab9c", "name": "monthly"},
            "prefix": "new_monthly",
            "count": 5,
            "snapmirror_label": "-",
        }
    )

### Updating a Snapshot copy policy schedule

The PATCH operation is used to update the specific attributes of a Snapshot copy policy.

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import SnapshotPolicySchedule

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = SnapshotPolicySchedule(
            "32a0841a-818e-11e9-b4f4-005056bbab9c",
            **{"schedule.uuid": "7c985d80-818a-11e9-b4f4-005056bbab9c"}
        )
        resource.count = "10"
        resource.patch()

### Deleting a Snapshot copy policy

The DELETE operation is used to delete a Snapshot copy policy.

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import SnapshotPolicySchedule

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = SnapshotPolicySchedule(
            "32a0841a-818e-11e9-b4f4-005056bbab9c",
            **{"schedule.uuid": "7c985d80-818a-11e9-b4f4-005056bbab9c"}
        )
        resource.delete()

## Classes

`class SnapshotPolicySchedule (*args, **kwargs)`

  The Snapshot copy policy schedule object is associated with a Snapshot copy policy and it defines the interval at which Snapshot copies are created and deleted.

  Initialize the instance of the resource.

  Any keyword arguments are set on the instance as properties. For example, if the class was named 'MyResource', then this statement would be true:

      MyResource(name='foo').name == 'foo'

  ## Args

  `*args`
    Each positional argument represents a parent key as used in the URL of the object. That is, each value will be used to fill in a segment of the URL which refers to some parent object. The order of these arguments must match the order they are specified in the URL, from left to right.
  `**kwargs`
    each entry will have its key set as an attribute name on the instance and its value will be the value of that attribute.

  ### Ancestors

  - Resource

  ### Static methods

  `def count_collection(*args, connection: HostConnection = None, **kwargs) -> int`

    Retrieves a collection of Snapshot copy policy schedules.

    ### Related ONTAP commands

    - `snapshot policy show`

    ### Learn more

    - `DOC /storage/snapshot-policies/{snapshot_policy.uuid}/schedules`

    Fetch a count of all objects of this type from the host.

    This calls GET on the object to determine the number of records. It is more efficient than calling get_collection() because it will not construct any objects. Query parameters can be passed in as kwargs to determine a count of objects that match some filtered criteria.

    ## Args

    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to get the count of bars for a particular foo, the foo.name value should be passed.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host. These query parameters can affect the count. A return_records query param will be ignored.

    ## Returns

    On success, returns an integer count of the objects of this type. On failure, returns -1.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400, or if there is no connection available to use either passed in or on the library.

  `def delete_collection(*args, body: typing.Union = None, connection: HostConnection = None, **kwargs) -> NetAppResponse`

    Deletes a schedule from a Snapshot copy policy

    ### Related ONTAP commands

    - `snapshot policy remove-schedule`

    ### Learn more

    - `DOC /storage/snapshot-policies/{snapshot_policy.uuid}/schedules`

    Delete all objects in a collection which match the given query.

    All records on the host which match the query will be deleted.

    ## Args

    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to delete the collection of bars for a particular foo, the foo.name value should be passed.
    `body`
      The body of the delete request. This could be a Resource instance or a dictionary object.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host. Only resources matching this query will be patched.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  `def find(*args, connection: HostConnection = None, **kwargs) -> Resource`

    Retrieves a collection of Snapshot copy policy schedules.

    ### Related ONTAP commands

    - `snapshot policy show`

    ### Learn more

    - `DOC /storage/snapshot-policies/{snapshot_policy.uuid}/schedules`

    Find an instance of an object on the host given a query.

    The host will be queried with the provided key/value pairs to find a matching resource. If 0 are found, None will be returned. If more than 1 is found, an error will be raised or returned. If there is exactly 1 matching record, then it will be returned.

    ## Args

    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to find a bar for a particular foo, the foo.name value should be passed.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host.

    ## Returns

    A `Resource` object containing the details of the object or None if no matches were found.

    ## Raises

    `NetAppRestError`: If the API call returned more than 1 matching resource.

  `def get_collection(*args, connection: HostConnection = None, max_records: int = None, **kwargs) -> typing.Iterable`

    Retrieves a collection of Snapshot copy policy schedules.

    ### Related ONTAP commands

    - `snapshot policy show`

    ### Learn more

    - `DOC /storage/snapshot-policies/{snapshot_policy.uuid}/schedules`

    Fetch a list of all objects of this type from the host.

    This is a lazy fetch, making API calls only as necessary when the result of this call is iterated over. For instance, if max_records is set to 5, then iterating over the collection causes an API call to be sent to the server once for every 5 records. If the client stops iterating before getting to the 6th record, then no additional API calls are made.

    ## Args

    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to get the collection of bars for a particular foo, the foo.name value should be passed.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `max_records`
      The maximum number of records to return per call
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host.

    ## Returns

    A list of `Resource` objects

    ## Raises

    `NetAppRestError`: If there is no connection available to use either passed in or on the library. This would be not be raised when get_collection() is called, but rather when the result is iterated.

  `def patch_collection(body: dict, *args, connection: HostConnection = None, **kwargs) -> NetAppResponse`

    Updates a Snapshot copy policy schedule

    ### Related ONTAP commands

    - `snapshot policy modify-schedule`

    ### Learn more

    - `DOC /storage/snapshot-policies/{snapshot_policy.uuid}/schedules`

    Patch all objects in a collection which match the given query.

    All records on the host which match the query will be patched with the provided body.

    ## Args

    `body`
      A dictionary of name/value pairs to set on all matching members of the collection.
    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to patch the collection of bars for a particular foo, the foo.name value should be passed.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host. Only resources matching this query will be patched.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  ### Methods

  `def delete(self, body: typing.Union = None, poll: bool = True, poll_interval: typing.Union = None, poll_timeout: typing.Union = None, **kwargs) -> NetAppResponse`

    Deletes a schedule from a Snapshot copy policy

    ### Related ONTAP commands

    - `snapshot policy remove-schedule`

    ### Learn more

    - `DOC /storage/snapshot-policies/{snapshot_policy.uuid}/schedules`

    Send a deletion request to the host for this object.

    ## Args

    `body`
      The body of the delete request. This could be a Resource instance or a dictionary object.
    `poll`
      If set to True, the call will not return until the asynchronous job on the host has completed. Has no effect if the host did not return a job response.
    `poll_interval`
      If the operation returns a job, this specifies how often to query the job for updates.
    `poll_timeout`
      If the operation returns a job, this specifies how long to continue monitoring the job's status for completion.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  `def get(self, **kwargs) -> NetAppResponse`

    Retrieves details of a specific Snapshot copy policy schedule.

    ### Related ONTAP commands

    - `snapshot policy show`

    ### Learn more

    - `DOC /storage/snapshot-policies/{snapshot_policy.uuid}/schedules`

    Fetch the details of the object from the host.

    Requires the keys to be set (if any). After returning, new or changed properties from the host will be set on the instance.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  `def patch(self, hydrate: bool = False, poll: bool = True, poll_interval: typing.Union = None, poll_timeout: typing.Union = None, **kwargs) -> NetAppResponse`

    Updates a Snapshot copy policy schedule

    ### Related ONTAP commands

    - `snapshot policy modify-schedule`

    ### Learn more

    - `DOC /storage/snapshot-policies/{snapshot_policy.uuid}/schedules`

    Send the difference in the object's state to the host as a modification request.

    Calculates the difference in the object's state since the last time we interacted with the host and sends this in the request body.

    ## Args

    `hydrate`
      If set to True, after the response is received from the call, a a GET call will be made to refresh all fields of the object.
    `poll`
      If set to True, the call will not return until the asynchronous job on the host has completed. Has no effect if the host did not return a job response.
    `poll_interval`
      If the operation returns a job, this specifies how often to query the job for updates.
    `poll_timeout`
      If the operation returns a job, this specifies how long to continue monitoring the job's status for completion.
    `**kwargs`
      Any key/value pairs passed will normally be sent as query parameters to the host. If any of these pairs are parameters that are sent as formdata then only parameters of that type will be accepted and all others will be discarded.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  `def post(self, hydrate: bool = False, poll: bool = True, poll_interval: typing.Union = None, poll_timeout: typing.Union = None, **kwargs) -> NetAppResponse`

    Adds a schedule to a Snapshot copy policy.

    ### Required properties

    - `schedule.uuid` or `schedule.name` - Schedule at which Snapshot copies are captured on the volume.
    - `count` - Number of Snapshot copies to maintain for this schedule.

    ### Recommended optional properties

    - `prefix` - Prefix to use when creating Snapshot copies at regular intervals.

    ### Default property values

    If not specified in POST, the following default property values are assigned: * `prefix` - Value of `schedule.name`

    ### Related ONTAP commands

    - `snapshot policy add-schedule`

    ### Learn more

    - `DOC /storage/snapshot-policies/{snapshot_policy.uuid}/schedules`

    Send this object to the host as a creation request.

    ## Args

    `hydrate`
      If set to True, after the response is received from the call, a a GET call will be made to refresh all fields of the object.
    `poll`
      If set to True, the call will not return until the asynchronous job on the host has completed. Has no effect if the host did not return a job response.
    `poll_interval`
      If the operation returns a job, this specifies how often to query the job for updates.
    `poll_timeout`
      If the operation returns a job, this specifies how long to continue monitoring the job's status for completion.
    `**kwargs`
      Any key/value pairs passed will normally be sent as query parameters to the host. If any of these pairs are parameters that are sent as formdata then only parameters of that type will be accepted and all others will be discarded.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  ### Inherited members

  - `Resource`:
    - `from_dict`
    - `get_collection_url`
    - `get_connection`
    - `instance_location`
    - `path_keys`
    - `poll`
    - `set_connection`
    - `to_dict`
`class SnapshotPolicyScheduleSchema (*, only: typing.Union = None, exclude: typing.Union = (), many: bool = False, context: typing.Dict = None, load_only: typing.Union = (), dump_only: typing.Union = (), partial: typing.Union = False, unknown: str = None)`

  The fields of the SnapshotPolicySchedule object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC

  ### Class variables

  `count GET POST PATCH`

    The number of Snapshot copies to maintain for this schedule.

  `links GET`

    The links field of the snapshot_policy_schedule.

  `prefix GET POST`

    The prefix to use while creating Snapshot copies at regular intervals.

  `schedule GET POST PATCH`

    The schedule field of the snapshot_policy_schedule.

  `snapmirror_label GET POST PATCH`

    Label for SnapMirror operations

  `snapshot_policy GET POST PATCH`

    The snapshot_policy field of the snapshot_policy_schedule.